Module: Taski::Progress::Layout::Tree::Structure

Included in:
Event, Live
Defined in:
lib/taski/progress/layout/tree/structure.rb

Overview

Shared tree structure logic for Tree::Live and Tree::Event. Provides tree building, node registration, prefix generation, and tree rendering methods.

Constant Summary collapse

BRANCH =

Tree connector characters

"├── "
LAST_BRANCH =
"└── "
VERTICAL =
""
SPACE =
"    "

Instance Method Summary collapse

Instance Method Details

#render_treeObject

Returns the tree structure as a string. Uses the current theme to render task content for each node.



19
20
21
# File 'lib/taski/progress/layout/tree/structure.rb', line 19

def render_tree
  build_tree_lines.join("\n") + "\n"
end