Class: Taski::Progress::Theme::Default
- Defined in:
- lib/taski/progress/theme/default.rb
Overview
Default theme inheriting from Theme::Base.
Note: Theme::Base provides ANSI color helper methods (color_red, color_green, etc.) which return escape codes by default. If Liquid templates or filters use these methods, output may contain escape codes.
For guaranteed plain text output without any terminal escape codes, use Theme::Plain instead, which overrides all color methods to return empty strings.
Method Summary
Methods inherited from Base
#clean_fail, #clean_start, #clean_success, #color_dim, #color_green, #color_red, #color_reset, #color_yellow, #execution_complete, #execution_fail, #execution_running, #execution_start, #format_count, #format_duration, #group_fail, #group_start, #group_success, #icon_failure, #icon_pending, #icon_skip, #icon_success, #render_interval, #spinner_frames, #spinner_interval, #task_fail, #task_pending, #task_skip, #task_start, #task_success, #truncate_list_separator, #truncate_list_suffix, #truncate_text_suffix